# Readme - Gefran PID
Python package to control Gefran PID temperature controllers.
Requires a Gefran PID controller, equiped with a Modbus RTU communication interface.
Tested with a Gefran 650 PID controller. 